# aio-dprcon

A library and console client for DarkPlaces RCON protocol


## Installation

```bash
$ pip install aio-dprcon
```


## Console tool usage


```bash
$ dprcon add  # Add a server
$ dprcon refresh SERVER_NAME  # Fill completion cache (optional)
$ dprcon connect SERVER_NAME  # Launch interactive RCON shell 
```


## Library API

To be written
